@@ -14,20 +14,16 @@
 
 """Hypervisor Stats action implementations"""
 
-import logging
-import six
+from osc_lib.command import command
 
-from cliff import show
+from openstackclient.i18n import _
 
 
-class ShowHypervisorStats(show.ShowOne):
-    """Display hypervisor stats details"""
-
-    log = logging.getLogger(__name__ + ".ShowHypervisorStats")
+class ShowHypervisorStats(command.ShowOne):
+    _description = _("Display hypervisor stats details")
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)", parsed_args)
         compute_client = self.app.client_manager.compute
         hypervisor_stats = compute_client.hypervisors.statistics().to_dict()
 
-        return zip(*sorted(six.iteritems(hypervisor_stats)))
+        return zip(*sorted(hypervisor_stats.items()))
