@@ -51,7 +51,6 @@ _formatters = {
     'dns_assignment': format_columns.ListDictColumn,
     'extra_dhcp_opts': format_columns.ListDictColumn,
     'fixed_ips': format_columns.ListDictColumn,
-    'location': format_columns.DictColumn,
     'security_group_ids': format_columns.ListColumn,
     'tags': format_columns.ListColumn,
 }
@@ -515,6 +514,10 @@ class ListPort(command.Lister):
                    "This is the entity that uses the port (for example, "
                    "network:dhcp).")
         )
+        parser.add_argument(
+            '--host',
+            metavar='<host-id>',
+            help=_("List only ports bound to this host ID"))
         parser.add_argument(
             '--network',
             metavar='<network>',
@@ -603,6 +606,8 @@ class ListPort(command.Lister):
             server = utils.find_resource(compute_client.servers,
                                          parsed_args.server)
             filters['device_id'] = server.id
+        if parsed_args.host:
+            filters['binding:host_id'] = parsed_args.host
         if parsed_args.network:
             network = network_client.find_network(parsed_args.network,
                                                   ignore_missing=False)
