@@ -25,7 +25,6 @@ from osc_lib import shell
 import six
 
 import openstackclient
-from openstackclient.common import client_config as cloud_config
 from openstackclient.common import clientmanager
 
 
@@ -58,10 +57,10 @@ class OpenStackShell(shell.OpenStackShell):
     def _final_defaults(self):
         super(OpenStackShell, self)._final_defaults()
 
-        # Set the default plugin to token_endpoint if url and token are given
-        if (self.options.url and self.options.token):
-            # Use service token authentication
-            self._auth_type = 'token_endpoint'
+        # Set the default plugin to admin_token if endpoint and token are given
+        if (self.options.endpoint and self.options.token):
+            # Use token authentication
+            self._auth_type = 'admin_token'
         else:
             self._auth_type = 'password'
 
@@ -133,69 +132,13 @@ class OpenStackShell(shell.OpenStackShell):
     def initialize_app(self, argv):
         super(OpenStackShell, self).initialize_app(argv)
 
-        # Argument precedence is really broken in multiple places
-        # so we're just going to fix it here until o-c-c and osc-lib
-        # get sorted out.
-        # TODO(dtroyer): remove when os-client-config and osc-lib are fixed
-
-        # First, throw away what has already been done with o-c-c and
-        # use our own.
-        try:
-            self.cloud_config = cloud_config.OSC_Config(
-                override_defaults={
-                    'interface': None,
-                    'auth_type': self._auth_type,
-                },
-            )
-        except (IOError, OSError):
-            self.log.critical("Could not read clouds.yaml configuration file")
-            self.print_help_if_requested()
-            raise
-
-        if not self.options.debug:
-            self.options.debug = None
-
-        # NOTE(dtroyer): Need to do this with validate=False to defer the
-        #                auth plugin handling to ClientManager.setup_auth()
-        self.cloud = self.cloud_config.get_one_cloud(
-            cloud=self.options.cloud,
-            argparse=self.options,
-            validate=False,
-        )
-
-        # Then, re-create the client_manager with the correct arguments
+        # Re-create the client_manager with our subclass
         self.client_manager = clientmanager.ClientManager(
             cli_options=self.cloud,
             api_version=self.api_version,
             pw_func=shell.prompt_for_password,
         )
 
-    def prepare_to_run_command(self, cmd):
-        """Set up auth and API versions"""
-
-        # TODO(dtroyer): Move this to osc-lib, remove entire method when 1.4.0
-        #                release is minimum version is in global-requirements
-        # NOTE(dtroyer): If auth is not required for a command, skip
-        #                get_one_Cloud()'s validation to avoid loading plugins
-        validate = cmd.auth_required
-
-        # Force skipping auth for commands that do not need it
-        # NOTE(dtroyer): This is here because ClientManager does not have
-        #                visibility into the Command object to get
-        #                auth_required. It needs to move into osc-lib
-        self.client_manager._auth_required = cmd.auth_required
-
-        # Validate auth options
-        self.cloud = self.cloud_config.get_one_cloud(
-            cloud=self.options.cloud,
-            argparse=self.options,
-            validate=validate,
-        )
-        # Push the updated args into ClientManager
-        self.client_manager._cli_options = self.cloud
-
-        return super(OpenStackShell, self).prepare_to_run_command(cmd)
-
 
 def main(argv=None):
     if argv is None:
@@ -209,5 +152,6 @@ def main(argv=None):
 
     return OpenStackShell().run(argv)
 
+
 if __name__ == "__main__":
     sys.exit(main())
